@@ -1,6 +1,5 @@
 import sys, os
-sys.path.insert(0, os.path.join(
-    os.path.dirname(os.path.dirname(__file__)), 'formencode'))
+sys.path.insert(0, os.path.dirname(os.path.dirname(__file__)))
 import pkg_resources
 try:
     import elementtree
